==> 0.0.5.tar.gz: lib/src/field_list_view.dart <==
library fields.field_list_view;

import 'dart:html';
import 'package:tags/builder.dart';
import 'package:tags/custom.dart';
import 'package:tags/html.dart';
import 'field.dart';
import 'theme.dart';
import 'field_view.dart';

final Tag fieldListView = 
    ([Build b, Bind onBind]) => 
        build(() => bind(new FieldListView(), onBind), b);

class FieldListViewResources {
  String get style =>
"""
table {
  border-collapse:collapse;
  border-top:1px solid ${fieldsTheme.colors.border};
  border-left:1px solid ${fieldsTheme.colors.border};
  margin:-1px;            
  padding:0px;
  table-layout:fixed;
  width:100%;
}
td {
  background-color: ${fieldsTheme.colors.fieldBackground};
  border-top:1px solid ${fieldsTheme.colors.border};
  border-left:1px solid ${fieldsTheme.colors.border};
  color: ${fieldsTheme.colors.text};
  vertical-align:text-top;
  margin:0px;
  overflow:hidden;
  padding:0px;
  text-overflow:ellipsis;
}
.namebox {
  padding-left:4px;
  width:20%;
}
""";
  const FieldListViewResources();
}

class FieldListView implements HasElement {  
  final Map<Field, List> _cache = new Map<Field, List>();
  Element _tbody;
  Element _element;
  Element get element => _element;    
    
  FieldListView([FieldListViewResources res = const FieldListViewResources()]) {
    _element =
        span(() {
          style()
            ..scoped = true
            ..text = res.style;
          table(() => _tbody = tbody());
        });
  }

  void clearCache() => _cache.clear();
  
  void render(List<Field> fields) {
    _tbody.children.clear();
    for (var f in fields) {        
      if (_cache.containsKey(f)) {
        _tbody.append(_cache[f][0]);
        _cache[f][1].render();
      } else {
        FieldView item;
        final el = tr(() {
          td(() => span()..text = f.displayName)
            ..title = f.displayName
            ..classes = ['namebox'];
          td(() => fieldView(null, [f, (FieldView model) => item = model]));
        });
        _cache[f] = [el, item];
        _tbody.append(el);
      }
    }
  }
}

==> 0.0.8.tar.gz: lib/src/field_list_view.dart <==
library fields.field_list_view;

import 'dart:html';
import 'package:tags/tags.dart';
import 'field.dart';
import 'theme.dart';
import 'field_view.dart';

final Tag fieldListView = 
    ([BuildChildren b, BindModel onBind]) => 
        buildNode(() => bindModel(new FieldListView(), onBind), b);

class FieldListViewResources {
  String get style =>
"""
table {
  border-collapse:collapse;
  border-top:1px solid ${fieldsTheme.colors.border};
  border-left:1px solid ${fieldsTheme.colors.border};
  margin:-1px;            
  padding:0px;
  table-layout:fixed;
  width:100%;
}
td {
  background-color: ${fieldsTheme.colors.fieldBackground};
  border-top:1px solid ${fieldsTheme.colors.border};
  border-left:1px solid ${fieldsTheme.colors.border};
  color: ${fieldsTheme.colors.text};
  vertical-align:text-top;
  margin:0px;
  overflow:hidden;
  padding:0px;
  text-overflow:ellipsis;
}
.namebox {
  padding-left:4px;
  width:20%;
}
""";
  const FieldListViewResources();
}

class FieldListView implements HasElement {  
  final Map<Field, List> _cache = new Map<Field, List>();
  Element _tbody;
  Element _element;
  Element get element => _element;    
    
  FieldListView([FieldListViewResources res = const FieldListViewResources()]) {
    _element =
        span(() {
          style()
            ..scoped = true
            ..text = res.style;
          table(() => _tbody = tbody());
        });
  }

  void clearCache() => _cache.clear();
  
  void render(List<Field> fields) {
    _tbody.children.clear();
    for (var f in fields) {        
      if (_cache.containsKey(f)) {
        _tbody.append(_cache[f][0]);
        _cache[f][1].render();
      } else {
        FieldView item;
        final el = tr(() {
          td(() => span()..text = f.displayName)
            ..title = f.displayName
            ..classes = ['namebox'];
          td(() => fieldView(null, [f, (FieldView model) => item = model]));
        });
        _cache[f] = [el, item];
        _tbody.append(el);
      }
    }
  }
}
